import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';

const iconContent = new Map();
const requests = new Map();
const getSvgContent = (url) => {
  let req = requests.get(url);
  if (!req) {
    req = fetch(url).then(rsp => {
      if (rsp.ok) {
        return rsp.text().then(svgContent => {
          iconContent.set(url, svgContent || '');
        });
      }
      iconContent.set(url, '');
    });
    requests.set(url, req);
  }
  return req;
};

const fIconsCss = ":host{display:block}";

const FIcons$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.group = 'default';
    this.size = '20';
  }
  async componentWillLoad() {
    this.sym = Symbol.for('@facilio/icons/config');
    await this.loadIcon();
  }
  async loadIcon() {
    var _a;
    // give the cdn url or url based on the init function
    let cdnUrl = 'https://static.facilio.com/icons/svg/';
    let baseUrl = ((_a = window[this.sym]) === null || _a === void 0 ? void 0 : _a.baseUrl) ? window[this.sym].baseURL : cdnUrl;
    const url = `${baseUrl}${this.group}/${this.name}.svg`;
    if (iconContent.has(url)) {
      this.svgContent = iconContent.get(url);
    }
    else {
      await getSvgContent(url).then(() => (this.svgContent = iconContent.get(url)));
    }
    let styledSvg = `<svg class="${this.iconClass ? this.iconClass : 'icon'}" style="height:${this.size}px; width: ${this.size}px; fill: ${this.color}"`;
    styledSvg = this.svgContent.replace(/<svg/, styledSvg);
    this.icon = styledSvg;
  }
  render() {
    return h("div", { class: "svg-container", innerHTML: this.icon });
  }
  static get watchers() { return {
    "name": ["componentWillLoad"],
    "icon": ["componentWillLoad"]
  }; }
  static get style() { return fIconsCss; }
}, [1, "f-icons", {
    "name": [1],
    "group": [1],
    "size": [1],
    "color": [1],
    "svgContent": [32],
    "iconClass": [32],
    "icon": [32],
    "baseURL": [32],
    "sym": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["f-icons"];
  components.forEach(tagName => { switch (tagName) {
    case "f-icons":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, FIcons$1);
      }
      break;
  } });
}

const FIcons = FIcons$1;
const defineCustomElement = defineCustomElement$1;

export { FIcons, defineCustomElement };
