import { r as registerInstance, h } from './index-c3f630a2.js';

const iconContent = new Map();
const requests = new Map();
const getSvgContent = (url) => {
  let req = requests.get(url);
  if (!req) {
    req = fetch(url).then(rsp => {
      if (rsp.ok) {
        return rsp.text().then(svgContent => {
          iconContent.set(url, svgContent || '');
        });
      }
      iconContent.set(url, '');
    });
    requests.set(url, req);
  }
  return req;
};

const fIconsCss = ":host{display:block}";

const FIcons = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.group = 'default';
    this.size = '20';
  }
  async componentWillLoad() {
    this.sym = Symbol.for('@facilio/icons/config');
    await this.loadIcon();
  }
  async loadIcon() {
    var _a;
    // give the cdn url or url based on the init function
    let cdnUrl = 'https://static.facilio.com/icons/svg/';
    let baseUrl = ((_a = window[this.sym]) === null || _a === void 0 ? void 0 : _a.baseUrl) ? window[this.sym].baseURL : cdnUrl;
    const url = `${baseUrl}${this.group}/${this.name}.svg`;
    if (iconContent.has(url)) {
      this.svgContent = iconContent.get(url);
    }
    else {
      await getSvgContent(url).then(() => (this.svgContent = iconContent.get(url)));
    }
    let styledSvg = `<svg class="${this.iconClass ? this.iconClass : 'icon'}" style="height:${this.size}px; width: ${this.size}px; fill: ${this.color}"`;
    styledSvg = this.svgContent.replace(/<svg/, styledSvg);
    this.icon = styledSvg;
  }
  render() {
    return h("div", { class: "svg-container", innerHTML: this.icon });
  }
  static get watchers() { return {
    "name": ["componentWillLoad"],
    "icon": ["componentWillLoad"]
  }; }
};
FIcons.style = fIconsCss;

export { FIcons as F };
